@@ -1,7 +1,7 @@
 #!/usr/bin/perl
 ######################
 #
-#    Copyright (C) 2011  TU Clausthal, Institut fuer Maschinenwesen, Joachim Langenbach
+#    Copyright (C) 2011 - 2015 TU Clausthal, Institut fuer Maschinenwesen, Joachim Langenbach
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -26,7 +26,7 @@ use warnings;
 
 package CAD::Firemen;
 {
-  $CAD::Firemen::VERSION = '0.6.2';
+  $CAD::Firemen::VERSION = '0.7.0';
 }
 
 use CAD::Firemen::Analyze;
@@ -35,6 +35,8 @@ use CAD::Firemen::Change::Type;
 use CAD::Firemen::Common qw(maxLength);
 use CAD::Firemen::Load;
 use CAD::Firemen::Option::Check;
+use CAD::Firemen::ParseHelp::Wildfire5;
+use CAD::Firemen::ParseHelp::Creo3;
 
 sub printVersion {
   my %versions = ();
@@ -45,6 +47,8 @@ sub printVersion {
   $versions{'CAD::Firemen::Common'} = $CAD::Firemen::Common::VERSION;
   $versions{'CAD::Firemen::Load'} = $CAD::Firemen::Load::VERSION;
   $versions{'CAD::Firemen::Option::Check'} = $CAD::Firemen::Option::Check::VERSION;
+  $versions{'CAD::Firemen::ParseHelp::Wildfire5'} = $CAD::Firemen::ParseHelp::Wildfire5::VERSION;
+  $versions{'CAD::Firemen::ParseHelp::Creo3'} = $CAD::Firemen::ParseHelp::Creo3::VERSION;
 
   print "The version of the bundled firefighters and modules are:\n";
   my $max = maxLength(keys(%versions)) + 2;
@@ -66,7 +70,7 @@ CAD::Firemen - Scripts and Modules to manage PTC(R) ProE/Engineer(R) / Creo(TM)
 
 =head1 VERSION
 
-version 0.6.2
+version 0.7.0
 
 =head1 SYNOPSIS
 
@@ -161,7 +165,7 @@ Joachim Langenbach <langenbach@imw.tu-clausthal.de>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2011 by TU Clausthal, Institut fuer Maschinenwesen.
+This software is Copyright (c) 2015 by TU Clausthal, Institut fuer Maschinenwesen.
 
 This is free software, licensed under:
 
