@@ -1,7 +1,7 @@
 #!/usr/bin/perl
 ######################
 #
-#    Copyright (C) 2011 - 2013 TU Clausthal, Institut fuer Maschinenwesen, Joachim Langenbach
+#    Copyright (C) 2011 - 2015 TU Clausthal, Institut fuer Maschinenwesen, Joachim Langenbach
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -26,7 +26,7 @@ use warnings;
 
 package CAD::Firemen::Common;
 {
-  $CAD::Firemen::Common::VERSION = '0.6.2';
+  $CAD::Firemen::Common::VERSION = '0.7.0';
 }
 use Exporter 'import';
 our @EXPORT_OK = qw(
@@ -70,6 +70,7 @@ use File::Path;
 use DBI;
 use YAML::XS qw(DumpFile LoadFile);
 use File::Path qw(rmtree);
+use File::Find::Rule;
 # Auto reset colors after print line
 #$Term::ANSIColor::AUTORESET = 1;
 
@@ -87,12 +88,10 @@ sub untaint {
   if(!defined($string)){
     return "";
   }
-  if($string =~ /^([\w\.\s\-\@\:\(\)\!\?\=\+\[\]\$\"\,\|\/\\]+)$/gs){
+  if($string =~ /^([\w\.\s\-\@\:\(\)\!\?\=\+\[\]\$\"\,\|\/\\;~]+)$/gs){
     return $1;
   }
-  else{
-    return "";
-  }
+  return "";
 }
 
 sub print2ColsRightAligned {
@@ -152,6 +151,7 @@ sub printColored {
   my $text = untaint(shift);
   my $indent = untaint(shift);
   my $color = untaint(shift);
+
   if(!defined($text)){
     return;
   }
@@ -224,32 +224,60 @@ sub getInstallationPath {
   my $result = "";
   my @tempPaths = ($ENV{'PATH'} =~ m/;([^;]+(?:proe|creo)[^;]+);/gi);
   my @paths = ();
-  for(my $i = 0; $i < scalar(@tempPaths); $i++){
-    if($tempPaths[$i] =~ m/([\W\w]+)(?:\\|\/)mech(?:\\|\/)bin/i){
-      $tempPaths[$i] = $1;
-    }
-    elsif($tempPaths[$i] =~ m/([\W\w]+)(?:\\|\/)bin/i){
-      $tempPaths[$i] = $1;
-    }
-    if($tempPaths[$i] ne ""){
-      push(@paths, $tempPaths[$i]);
-    }
-  }
-  # add the paths from config, if they are not already found
+  # add the paths from config
   my $config = loadSettings();
   if(defined($config)){
     if(exists($config->{"paths"})){
       foreach my $dir (@{$config->{"paths"}}){
-        my $add = 1;
-        foreach my $existing (@paths){
-          if($existing eq $dir){
-            $add = 0;
-            last;
-          }
+        push(@paths, $dir);
+      }
+    }
+  }
+
+  # add path from ENV{PATH}, if not already done
+  for(my $i = 0; $i < scalar(@tempPaths); $i++){
+    if($tempPaths[$i] =~ m/([\W\w]+)(?:\\|\/)mech(?:\\|\/)bin/i){
+      $tempPaths[$i] = $1;
+    }
+    elsif($tempPaths[$i] =~ m/([\W\w]+)(?:\\|\/)Parametric{0,1}(?:\\|\/)bin$/i){
+      $tempPaths[$i] = $1;
+
+      my $alreadyInserted = 0;
+      foreach my $existing (@paths){
+        if(index($existing, $tempPaths[$i]) != -1){
+          $alreadyInserted = 1;
+          last;
         }
-        if($add){
-          push(@paths, $dir);
+      }
+      if($alreadyInserted){
+        $tempPaths[$i] = "";
+      }
+      else{
+        # only search for common files, if path is not already added!
+        print "Searching for Common Files directory of installation ". $tempPaths[$i] ."\n";
+        my @commonFilesDirectories = File::Find::Rule->name("Common Files")->in($tempPaths[$i]);
+        if(scalar(@commonFilesDirectories) == 1){
+          testPassed("  Found Common Files for ". $tempPaths[$i]);
+          $tempPaths[$i] = $commonFilesDirectories[0];
         }
+        else{
+          testFailed("  Found Common Files for ". $tempPaths[$i]);
+        }
+      }
+    }
+    elsif($tempPaths[$i] =~ m/([\W\w]+)(?:\\|\/)bin$/i){
+      $tempPaths[$i] = $1;
+    }
+    if($tempPaths[$i] ne ""){
+      my $add = 1;
+      foreach my $existing (@paths){
+        if($existing eq $tempPaths[$i]){
+          $add = 0;
+          last;
+        }
+      }
+      if($add){
+        push(@paths, $tempPaths[$i]);
       }
     }
   }
@@ -464,7 +492,7 @@ CAD::Firemen::Common - Shared functions used by other scripts from the Firemen m
 
 =head1 VERSION
 
-version 0.6.2
+version 0.7.0
 
 =head1 METHODS
 
@@ -585,7 +613,7 @@ Joachim Langenbach <langenbach@imw.tu-clausthal.de>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2011 by TU Clausthal, Institut fuer Maschinenwesen.
+This software is Copyright (c) 2015 by TU Clausthal, Institut fuer Maschinenwesen.
 
 This is free software, licensed under:
 
